@@ -1,6 +1,6 @@
 /* Lisp eval
 
-   Copyright (c) 2001, 2005-2011 Free Software Foundation, Inc.
+   Copyright (c) 2001-2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -69,7 +69,7 @@ get_function (const char *name)
 }
 
 /* Return function's interactive flag, or -1 if not found. */
-int
+bool
 get_function_interactive (const char *name)
 {
   fentry * f = get_fentry (name);
@@ -187,26 +187,22 @@ leEval (le * list)
 }
 
 le *
-execute_with_uniarg (bool undo, int uniarg, bool (*forward) (void), bool (*backward) (void))
+execute_with_uniarg (int uniarg, bool (*forward) (void), bool (*backward) (void))
 {
   if (backward && uniarg < 0)
     {
       forward = backward;
       uniarg = -uniarg;
     }
-  if (undo)
-    undo_start_sequence ();
   bool ret = true;
   for (int uni = 0; ret && uni < uniarg; ++uni)
     ret = forward ();
-  if (undo)
-    undo_end_sequence ();
 
   return bool_to_lisp (ret);
 }
 
 le *
-move_with_uniarg (int uniarg, bool (*move) (int dir))
+move_with_uniarg (int uniarg, bool (*move) (ptrdiff_t dir))
 {
   bool ret = true;
   for (unsigned long uni = 0; ret && uni < (unsigned) abs (uniarg); ++uni)
@@ -233,11 +229,11 @@ Read function name, then read its arguments and call it.
       if (lastflag & FLAG_UNIARG_EMPTY)
         msg = astr_fmt ("C-u ");
       else
-        msg = astr_fmt ("%d ", uniarg);
+        msg = astr_fmt ("%ld ", uniarg);
     }
   astr_cat_cstr (msg, "M-x ");
 
-  castr name = minibuf_read_function_name (astr_cstr (msg));
+  const_astr name = minibuf_read_function_name ("%s", astr_cstr (msg));
   if (name == NULL)
     return false;
 
@@ -248,12 +244,12 @@ END_DEFUN
 /*
  * Read a function name from the minibuffer.
  */
-static History *functions_history = NULL;
-castr
+static History functions_history = NULL;
+const_astr
 minibuf_read_function_name (const char *fmt, ...)
 {
   va_list ap;
-  Completion *cp = completion_new (false);
+  Completion cp = completion_new (false);
 
   for (size_t i = 0; i < fentry_table_size; ++i)
     if (fentry_table[i].interactive)
@@ -261,7 +257,7 @@ minibuf_read_function_name (const char *fmt, ...)
                          xstrdup (fentry_table[i].name));
 
   va_start (ap, fmt);
-  castr ms = minibuf_vread_completion (fmt, "", cp, functions_history,
+  const_astr ms = minibuf_vread_completion (fmt, "", cp, functions_history,
                                        "No function name given",
                                        minibuf_test_in_completions,
                                        "Undefined function name `%s'", ap);
