@@ -41,26 +41,26 @@ struct var_entry
   bool local;			/* If true, becomes local when set. */
   const char *doc;              /* Documentation */
 };
-typedef struct var_entry var_entry;
+typedef struct var_entry *var_entry;
 
 static Hash_table *main_vars;
 
 static size_t
 var_hash (const void *v, size_t n)
 {
-  return hash_string (((const var_entry *) v)->var, n);
+  return hash_string (((var_entry) v)->var, n);
 }
 
 static bool
 var_cmp (const void *v, const void *w)
 {
-  return STREQ (((const var_entry *) v)->var, ((const var_entry *) w)->var);
+  return STREQ (((var_entry) v)->var, ((var_entry) w)->var);
 }
 
 static void
 init_builtin_var (const char *var, const char *defval, bool local, const char *doc)
 {
-  var_entry *p = XZALLOC (var_entry);
+  var_entry p = XZALLOC (struct var_entry);
   p->var = xstrdup (var);
   p->defval = xstrdup (defval);
   p->val = xstrdup (defval);
@@ -90,8 +90,8 @@ void
 set_variable (const char *var, const char *val)
 {
   Hash_table *var_list;
-  struct var_entry *ent, *key = XZALLOC (var_entry);
-  var_entry *p = XZALLOC (var_entry), *q;
+  var_entry ent, key = XZALLOC (struct var_entry);
+  var_entry p = XZALLOC (struct var_entry), q;
 
   /* Find whether variable is buffer-local when set, and if needed
      create a buffer-local variable list. */
@@ -120,38 +120,34 @@ set_variable (const char *var, const char *val)
     }
 }
 
-static var_entry *
-get_variable_entry (Buffer * bp, const char *var)
+static var_entry
+get_variable_entry (Buffer bp, const char *var)
 {
-  var_entry *p = NULL, *key = XZALLOC (var_entry);
+  var_entry p = NULL, key = XZALLOC (struct var_entry);
 
   key->var = xstrdup (var);
 
   if (bp && get_buffer_vars (bp))
     p = hash_lookup (get_buffer_vars (bp), key);
 
-  if (p == NULL)
-    p = hash_lookup (main_vars, key);
-
-  return p;
+  return p ? p : hash_lookup (main_vars, key);
 }
 
 const char *
 get_variable_doc (const char *var, const char **defval)
 {
-  var_entry *p = get_variable_entry (NULL, var);
-  if (p != NULL)
-    {
-      *defval = p->defval;
-      return p->doc;
-    }
-  return NULL;
+  var_entry p = get_variable_entry (NULL, var);
+  if (p == NULL)
+    return NULL;
+
+  *defval = p->defval;
+  return p->doc;
 }
 
-static const char *
-get_variable_bp (Buffer * bp, const char *var)
+const char *
+get_variable_bp (Buffer bp, const char *var)
 {
-  var_entry *p = get_variable_entry (bp, var);
+  var_entry p = get_variable_entry (bp, var);
   return p ? p->val : NULL;
 }
 
@@ -161,25 +157,6 @@ get_variable (const char *var)
   return get_variable_bp (cur_bp, var);
 }
 
-long
-get_variable_number_bp (Buffer * bp, const char *var)
-{
-  long t = 0;
-  const char *s = get_variable_bp (bp, var);
-
-  if (s)
-    t = strtol (s, NULL, 10);
-  /* FIXME: Check result and signal error. */
-
-  return t;
-}
-
-long
-get_variable_number (const char *var)
-{
-  return get_variable_number_bp (cur_bp, var);
-}
-
 bool
 get_variable_bool (const char *var)
 {
@@ -190,12 +167,12 @@ get_variable_bool (const char *var)
   return false;
 }
 
-castr
+const_astr
 minibuf_read_variable_name (const char *fmt, ...)
 {
-  Completion *cp = completion_new (false);
+  Completion cp = completion_new (false);
 
-  for (var_entry *p = hash_get_first (main_vars);
+  for (var_entry p = hash_get_first (main_vars);
        p != NULL;
        p = hash_get_next (main_vars, p))
     {
@@ -205,10 +182,10 @@ minibuf_read_variable_name (const char *fmt, ...)
 
   va_list ap;
   va_start (ap, fmt);
-  castr ms = minibuf_vread_completion (fmt, "", cp, NULL,
-                                       "No variable name given",
-                                       minibuf_test_in_completions,
-                                       "Undefined variable name `%s'", ap);
+  const_astr ms = minibuf_vread_completion (fmt, "", cp, NULL,
+                                            "No variable name given",
+                                            minibuf_test_in_completions,
+                                            "Undefined variable name `%s'", ap);
   va_end (ap);
 
   return ms;
@@ -228,7 +205,7 @@ Set a variable value to the user-specified value.
     return leNIL;
   STR_INIT (val)
   else
-    val = minibuf_read ("Set %s to value: ", "", var);
+    val = minibuf_read ("Set %s to value: ", "", astr_cstr (var));
   if (val == NULL)
     ok = FUNCALL (keyboard_quit);
 
